@@ -13,25 +13,19 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.bcel.generic;
 
-/** 
- * Thrown on internal errors. Extends RuntimeException so it hasn't to be declared
- * in the throws clause every time.
- *
- * @version $Id: ClassGenException.java 1747278 2016-06-07 17:28:43Z britter $
+/**
+ * Thrown on internal errors. Extends RuntimeException so it hasn't to be declared in the throws clause every time.
  */
 public class ClassGenException extends RuntimeException {
 
     private static final long serialVersionUID = 7247369755051242791L;
 
     public ClassGenException() {
-        super();
     }
 
-
     public ClassGenException(final String s) {
         super(s);
     }
