@@ -13,7 +13,6 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.bcel.verifier.structurals;
 
@@ -811,13 +810,7 @@ public class ExecutionVisitor extends EmptyVisitor {
         stack().push(Type.INT);
     }
 
-    /**
-     * Symbolically executes the corresponding Java Virtual Machine instruction.
-     *
-     * @since 6.0
-     */
-    @Override
-    public void visitINVOKEDYNAMIC(final INVOKEDYNAMIC o) {
+    private void visitInvokedInternals(final InvokeInstruction o) {
         stack().pop(o.getArgumentTypes(cpg).length);
         // We are sure the invoked method will xRETURN eventually
         // We simulate xRETURNs functionality here because we
@@ -832,6 +825,16 @@ public class ExecutionVisitor extends EmptyVisitor {
         }
     }
 
+    /**
+     * Symbolically executes the corresponding Java Virtual Machine instruction.
+     *
+     * @since 6.0
+     */
+    @Override
+    public void visitINVOKEDYNAMIC(final INVOKEDYNAMIC o) {
+        visitInvokedInternals(o);
+    }
+
     /** Symbolically executes the corresponding Java Virtual Machine instruction. */
     @Override
     public void visitINVOKEINTERFACE(final INVOKEINTERFACE o) {
@@ -879,18 +882,7 @@ public class ExecutionVisitor extends EmptyVisitor {
     /** Symbolically executes the corresponding Java Virtual Machine instruction. */
     @Override
     public void visitINVOKESTATIC(final INVOKESTATIC o) {
-        stack().pop(o.getArgumentTypes(cpg).length);
-        // We are sure the invoked method will xRETURN eventually
-        // We simulate xRETURNs functionality here because we
-        // don't really "jump into" and simulate the invoked
-        // method.
-        if (o.getReturnType(cpg) != Type.VOID) {
-            Type t = o.getReturnType(cpg);
-            if (t.equals(Type.BOOLEAN) || t.equals(Type.CHAR) || t.equals(Type.BYTE) || t.equals(Type.SHORT)) {
-                t = Type.INT;
-            }
-            stack().push(t);
-        }
+        visitInvokedInternals(o);
     }
 
     /** Symbolically executes the corresponding Java Virtual Machine instruction. */
